[]Struct samp::consts::Supports

pub struct Supports { /* fields omitted */ }

Methods

impl Supports

pub const VERSION: Supports

pub const AMX_NATIVES: Supports

pub const PROCESS_TICK: Supports

pub fn empty() -> Supports

Returns an empty set of flags.

pub fn all() -> Supports

Returns the set containing all flags.

pub fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<Supports>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub fn from_bits_truncate(bits: u32) -> Supports

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub fn intersects(&self, other: Supports) -> bool

Returns true if there are flags common to both self and other.

pub fn contains(&self, other: Supports) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: Supports)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Supports)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Supports)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Supports, value: bool)

Inserts or removes the specified flags depending on the passed value.